==> web2ldap-0.15.10.tar.gz: web2ldap-0.15.10/pylib/w2lapp/referral.py <==
"""
w2lapp.referral.py: chase LDAP referrals

web2ldap - a web-based LDAP Client,
see http://www.web2ldap.de for details

(c) by Michael Stroeder <michael@stroeder.com>

This module is distributed under the terms of the
GPL (GNU GENERAL PUBLIC LICENSE) Version 2
(see http://www.gnu.org/copyleft/gpl.html)

$Id: referral.py,v 1.30 2004/04/27 19:45:51 michael Exp $
"""

import ldaputil.base,w2lapp.core,w2lapp.gui,w2lapp.cnf

from ldapurl import LDAPUrl

ErrorMessageDiv = """<div id="ErrorMessage" class="Main">
<h1>Error</h1>
<p>
  %s
</p>
</div>
"""

def w2l_ChaseReferral(sid,outf,command,form,ls,dn,e):

  w2lapp.gui.TopSection(
    sid,outf,form,ls,dn,
    'Referral received',
    w2lapp.gui.MainMenu(sid,form,ls,dn),
    context_menu_list=[]
  )

  # Pull out referral LDAP URL
  try:
    ldap_url_info = [
      s.strip()
      for s in e.args[0].get('info','').split('\n')
    ]
  except ValueError:
    outf.write(
      ErrorMessageDiv % (
        'Error extracting referral LDAP URL from %s.' % (
          w2lapp.core.utf2display(form.accept_charset,repr(e))
        )
      )
    )
    w2lapp.gui.PrintFooter(outf,form)
    return
  else:
    try:
      ldap_url_info = ldap_url_info[1]
    except IndexError,e:
      outf.write(
        ErrorMessageDiv % (
          'Error extracting referral LDAP URL from %s.' % (
            w2lapp.core.utf2display(form.accept_charset,repr(ldap_url_info))
          )
        )
      )
      w2lapp.gui.PrintFooter(outf,form)
      return
    # Parse the referral LDAP URL
    try:
      referralUrl = LDAPUrl(ldap_url_info[ldap_url_info.find('ldap:'):])
    except ValueError,e:
      outf.write(ErrorMessageDiv % (
          'Error parsing referral URL %s: %s' % (
            w2lapp.core.utf2display(form.accept_charset,repr(ldap_url_info)),
            w2lapp.core.utf2display(form.accept_charset,str(e))
          )
        )
      )
      w2lapp.gui.PrintFooter(outf,form)
      return

    # DN which triggered the referral
    matched_dn = e.args[0].get('matched','')
    matched_dn_list = ldaputil.base.explode_dn(matched_dn)
    referral_dn_list = ldaputil.base.explode_dn(referralUrl.dn)
    # determine new DN
    dn_list=ldaputil.base.explode_dn(dn)
    new_dn = ','.join(
      dn_list[0:len(dn_list)-len(matched_dn_list)]+referral_dn_list
    )

  login_template_str = open(w2lapp.gui.GetVariantFilename(
    w2lapp.cnf.GetParam(ls,'login_template'),form.accept_language
  ),'r').read()

  referral_uri = referralUrl.initializeUrl()

  login_fields = login_template_str % (
    referral_uri,
    w2lapp.core.utf2display(
      form.accept_charset,
      w2lapp.cnf.ldap_def.get(
        referral_uri,w2lapp.cnf.hosts.Web2LDAPConfig()
      ).get('description',u'')
    ),
    w2lapp.gui.SearchRootField(form,ls,dn,name='login_search_root').inputHTML(),
    w2lapp.core.utf2display(form.accept_charset,ls.who),
    w2lapp.core.utf2display(
      form.accept_charset,
      w2lapp.cnf.hosts.ldap_def.get(
        referral_uri,w2lapp.cnf.hosts.Web2LDAPConfig()
      ).get('binddnsearch','(uid=%%s)')
    ),
    form.field['login_mech'].inputHTML(),
    'Chase Referral',
  )

  outf.write("""<div id=InputDiv>
<h1>Referral received</h1>
<p>
  Referral URL: %s
</p>
<p>
  Referral DN %s matches %s =&gt; %s
</p>
"""  % (
      referralUrl.unparse(),
      w2lapp.gui.DisplayDN(sid,form,ls,referralUrl.dn),
      w2lapp.gui.DisplayDN(sid,form,ls,matched_dn),
      w2lapp.gui.DisplayDN(sid,form,ls,new_dn),
    )
  )
  outf.write("""
<form
  class="CommandForm"
  action="%s/%s/%s"
  method="POST"
  enctype="application/x-www-form-urlencoded"
  accept-charset="%s"
>
  <input type="hidden" name="host" value="%s">
  <input type="hidden" name="dn" value="%s">
  %s
"""  % (
        form.script_name,
        command,
        sid,
        form.accept_charset,
        referralUrl.hostport,
        w2lapp.core.utf2display(form.accept_charset,new_dn),
        login_fields,
      )
    )
  form.hiddenInputFields(outf,['sid','host','dn','who','cred','login_search_root'])
  outf.write('</form></div>\n')

  w2lapp.gui.PrintFooter(outf,form)

==> web2ldap-1.0.17.tar.gz: web2ldap-1.0.17/pylib/w2lapp/referral.py <==
"""
w2lapp.referral.py: chase LDAP referrals

web2ldap - a web-based LDAP Client,
see http://www.web2ldap.de for details

(c) by Michael Stroeder <michael@stroeder.com>

This module is distributed under the terms of the
GPL (GNU GENERAL PUBLIC LICENSE) Version 2
(see http://www.gnu.org/copyleft/gpl.html)

$Id: referral.py,v 1.35 2008/06/18 09:54:36 michael Exp $
"""

import ldaputil.base,w2lapp.core,w2lapp.gui,w2lapp.cnf

from ldapurl import LDAPUrl

ErrorMessageDiv = """<div id="ErrorMessage" class="Main">
<h1>Error</h1>
<p>
  %s
</p>
</div>
"""

def w2l_ChaseReferral(sid,outf,command,form,ls,dn,e):

  w2lapp.gui.TopSection(
    sid,outf,form,ls,dn,
    'Referral received',
    w2lapp.gui.MainMenu(sid,form,ls,dn),
    context_menu_list=[]
  )

  # Pull out referral LDAP URL
  try:
    ldap_url_info = [
      s.strip()
      for s in e.args[0].get('info','').split('\n')
    ]
  except ValueError:
    outf.write(
      ErrorMessageDiv % (
        'Error extracting referral LDAP URL from %s.' % (
          w2lapp.core.utf2display(form.accept_charset,repr(e))
        )
      )
    )
    w2lapp.gui.PrintFooter(outf,form)
    return
  else:
    try:
      ldap_url_info = ldap_url_info[1]
    except IndexError,e:
      outf.write(
        ErrorMessageDiv % (
          'Error extracting referral LDAP URL from %s.' % (
            w2lapp.core.utf2display(form.accept_charset,repr(ldap_url_info))
          )
        )
      )
      w2lapp.gui.PrintFooter(outf,form)
      return
    # Parse the referral LDAP URL
    try:
      referralUrl = LDAPUrl(ldap_url_info[ldap_url_info.find('ldap:'):])
    except ValueError,e:
      outf.write(ErrorMessageDiv % (
          'Error parsing referral URL %s: %s' % (
            w2lapp.core.utf2display(form.accept_charset,repr(ldap_url_info)),
            w2lapp.core.utf2display(form.accept_charset,str(e))
          )
        )
      )
      w2lapp.gui.PrintFooter(outf,form)
      return

    new_dn = referralUrl.dn

  login_template_filename = w2lapp.cnf.GetParam(ls,'login_template',None)
  login_template_filename = w2lapp.gui.GetVariantFilename(login_template_filename,form.accept_language)
  login_template_str = open(login_template_filename,'r').read()

  referral_uri = referralUrl.initializeUrl()

  login_search_root_field = w2lapp.gui.SearchRootField(form,ls,dn,name='login_search_root')
  login_fields = login_template_str % (
    form.field['login_mech'].inputHTML(),
    w2lapp.core.utf2display(form.accept_charset,ls.who),
    w2lapp.core.utf2display(form.accept_charset,w2lapp.cnf.GetParam(ls,'binddnsearch',r'(uid=%s)')),
    login_search_root_field.inputHTML(),
    'Chase Referral',
  )

  outf.write("""<div id="ErrorMessage" class="Main">
<h1>Referral received</h1>
<p>
  Referral URL: %s
</p>
"""  % (referralUrl.unparse()))
  outf.write("""
<form
  action="%s/%s/%s"
  method="POST"
  enctype="application/x-www-form-urlencoded"
  accept-charset="%s"
>
  <input type="hidden" name="host" value="%s">
  <input type="hidden" name="dn" value="%s">
  %s
"""  % (
        form.script_name,
        command,
        sid,
        form.accept_charset,
        referralUrl.hostport,
        w2lapp.core.utf2display(form.accept_charset,referralUrl.dn,escape_entities=1),
        login_fields,
      )
    )
  form.hiddenInputFields(outf,['sid','host','dn','who','cred','login_search_root'])
  outf.write('</form></div>\n')

  w2lapp.gui.PrintFooter(outf,form)
